import React, { Component, ReactElement } from 'react'

type HeaderOptions = {
  title: string
  shortDescription: string
  img?: {
    src: string
    alt?: string
  }
  children?: ReactElement[]
}

export default ({ title, shortDescription, img, children }: HeaderOptions) => {
  return (
    <section
      className="bg-white mt-32 w-full mx-auto relative z-10 pb-32"
      aria-labelledby="heading"
    >
      <h2 className="sr-only" id="heading">
        {title}
      </h2>
      <div className="flex flex-col bg-white rounded-b-lg shadow-xl">
        <div className="flex-1 relative pt-24 px-6 pb-8 md:px-8">
          <div className="h-32 absolute top-0 p-4 inline-block transform -translate-y-1/2">
            <header className={'flex items-end space-x-6'}>
              {img && (
                <img
                  src={img.src}
                  alt={img.alt ? img.alt : `${title} Logo`}
                  className={'w-24 h-24'}
                />
              )}
              <h1 className="text-5xl font-extrabold tracking-tight text-gray-900">
                {title}
              </h1>
            </header>
          </div>
          <div
            className="text-xl text-gray-800"
            dangerouslySetInnerHTML={{ __html: shortDescription }}
          />
        </div>
        <div className="p-6 bg-gray-50 rounded-b-lg md:px-8 flex flex-row items-center gap-16">
          {children}
        </div>
      </div>
    </section>
  )
}
