import React from 'react'

import PageHeaderCard from '@/components/PageHeaderCard'

type ServiceStatus = 'Alpha' | 'Beta' | 'Live'

type HeaderOptions = {
  title: string
  shortDescription: string
  img?: {
    src: string
    alt?: string
  }
  developer: {
    name: string
    link: string
  }
  contact: {
    name: string
    mailTo: string
  }
  status: ServiceStatus
  documentationURL: string
  sourceURL?: string
  tosURL?: string
  issuesURL?: string
}

export function Header({
  title,
  shortDescription,
  img,
  developer,
  contact,
  tosURL,
  status,
  documentationURL,
  sourceURL,
  issuesURL,
}: HeaderOptions) {
  return (
    <PageHeaderCard title={title} shortDescription={shortDescription} img={img}>
      <div className="sm:col-span-1 text-left">
        <dt className="text-sm font-medium text-gray-500">Entwickler</dt>
        <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
          <a href={developer.link} target={'_blank'}>
            {developer.name}
          </a>
        </dd>
      </div>
      <div className="sm:col-span-1">
        <dt className="text-sm font-medium text-gray-500">Kontakt</dt>
        <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
          <a
            target={'_blank'}
            onClick={(e) => {
              window.open(`mailto:${contact.mailTo}`, '_blank')
              e.preventDefault()
            }}
          >
            {contact.name}
          </a>
        </dd>
      </div>
      <div className="sm:col-span-1">
        <dt className="text-sm font-medium text-gray-500">Status</dt>
        <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
          {status}
        </dd>
      </div>
      <div className="sm:col-span-1">
        <dt className="text-sm font-medium text-gray-500">Dokumentation</dt>
        <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
          <a href={documentationURL} target={'_blank'}>
            {documentationURL}
          </a>
        </dd>
      </div>
      {sourceURL && (
        <div className="sm:col-span-1">
          <dt className="text-sm font-medium text-gray-500">Quellcode</dt>
          <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
            <a href={sourceURL} target={'_blank'}>
              {sourceURL}
            </a>
          </dd>
        </div>
      )}
      {tosURL && (
        <div className="sm:col-span-1">
          <dt className="text-sm font-medium text-gray-500">
            Nutzungsbedingungen
          </dt>
          <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
            <a href={tosURL} target={'_blank'}>
              {tosURL}
            </a>
          </dd>
        </div>
      )}
      {issuesURL && (
        <div className="sm:col-span-1">
          <dt className="text-sm font-medium text-gray-500">
            Nutzungsbedingungen
          </dt>
          <dd className="ml-0 mt-1 text-sm text-gray-900 hover:cursor-pointer">
            <a href={issuesURL} target={'_blank'}>
              {issuesURL}
            </a>
          </dd>
        </div>
      )}
    </PageHeaderCard>
  )
}
