import React, {ReactElement} from 'react'
import Link from 'next/link'
import { JSXElement } from '@babel/types'

export type FooterOptions = {
  copyright: string
  logo: {
    img: string
    alt?: string
  }
  children?: ReactElement[]
}

export type LinkEntry = {
  href: string
  label: string
}

export type FooterColumnOptions = {
  title: string
  links: LinkEntry[]
}

export function FooterColumn({ title, links }: FooterColumnOptions) {
  return (
    <>
      <div>
        <h3 className="text-sm font-semibold text-gray-400 tracking-wider uppercase">
          {title}
        </h3>
        <ul role="list" className="list-none m-0 p-0 mt-4 space-y-4">
          {links.map(({ href, label }, key) => (
            <li key={key}>
              <Link href={href} passHref>
                <a className="text-base text-gray-500 hover:text-gray-900">
                  {label}
                </a>
              </Link>
            </li>
          ))}
        </ul>
      </div>
    </>
  )
}

export function Footer({ logo, copyright, children }: FooterOptions) {
  return (
    <footer className="bg-white" aria-labelledby="footer-heading">
      <h2 id="footer-heading" className="sr-only">
        Footer
      </h2>
      <div className="max-w-7xl mx-auto pt-12 pb-8 px-4">
        <div className="justify-items-center xl:grid xl:grid-cols-5 xl:gap-8">
          <div className="space-y-4 xl:col-span-1">
            <Link href={'/'}>
              <img
                className="h-10 w-auto hover:cursor-pointer"
                src={logo.img}
                alt={logo.alt ? logo.alt : 'Logo'}
              />
            </Link>
            <p className="text-gray-500 text-base">
              Fit für die digitale Verwaltung.
              <br />
              Fit für die Zukunft.
            </p>
          </div>

          <div className="mt-12 col-span-3 grid grid-cols-3 gap-16 xl:mt-0">
            {children}
          </div>
        </div>

        {copyright ? (
          <div className="mt-12 border-t border-gray-200 pt-8">
            <p className="text-base text-gray-400 xl:text-center">
              Copyright &copy; {new Date().getFullYear()} {copyright}
            </p>
          </div>
        ) : null}.
        
        Wenn nicht anders vermerkt, sind die Inhalte dieser Webseite lizensiert unter der <a href="https://creativecommons.org/licenses/by/4.0/deed.de">Creative Commons Namensnennung 4.0 International Public License (CC BY 4.0)</a>.

      </div>
    </footer>
  )
}

